@@ -42,7 +42,6 @@ define("SELECT_GROUP_SQL", "SELECT * FROM loggroup;");
 
 define("REGEXP_ERR_NUM", 1139);
 
-
 /*********************************************************
  * make_hidden
  *
@@ -312,7 +311,6 @@ function printCSV($data)
     return;
 }
 
-
 /***********************************************************
  * 
  **********************************************************/
@@ -353,6 +351,8 @@ $tag["<<HIDDEN>>"]              = "";
 
 $page = 0;
 
+$groupdata = array();
+
 /* ե롢ִեɹåå */
 $ret = init();
 if ($ret === FALSE) {
@@ -389,51 +389,135 @@ if (isset($_POST["search_button"]) || isset($_POST["download_button"])) {
             exit(1);
         }
 
-        /* ʰ׸SQL */
-        $ret = make_easy_search_sql($conn, $post, $search_sql);
-        if ($ret === 2) {
-            mysqli_close($conn);
-            result_log(OPERATION . ":NG:" . $log_msg);
-            syserr_display();
-            exit(1);
-        /* ΥۥȤꤵ졢0郎ꤷ */
-        } else if ($ret === 3) {
-            mysqli_close($conn);
-            /* ֤ */
-            $tag["<<COMMENT_START>>"]       = "";
-            $tag["<<COMMENT_END>>"]         = "";
-            $tag["<<SEARCH_COUNT>>"]        = '0';
-            $err_msg = sprintf($msgarr['28022'][SCREEN_MSG], '0');
-            /* ݻhidden */
-            make_hidden($post, $tag);
-            /* ɥܥ󲡲 */
-            if (isset($_POST["download_button"])) {
-                /* ե̾ƥȥ꡼ॻå */
-                $fn = "log_" . date("YmdHis") . ".csv";
-                header("Content-Disposition: attachment; filename=\"$fn\"");
-                header("Content-Type: application/octet-stream");
-                exit(0);
-            }
-        } else if ($ret === 0) {
-            /* MySQL */
-            $result = MySQL_exec_query($conn, $search_sql);
-            $err_num = 0;
-            if ($result === FALSE) {
-                $err_num = mysqli_errno($conn);
+    /* פ "MYSQL" ξ */
+    if ($web_conf['sylas']['searchtype'] === MYSQL) {
+
+            /* ʰ׸SQL */
+            $ret = make_easy_search_sql($conn, $post, $search_sql);
+            if ($ret === 2) {
                 mysqli_close($conn);
+                result_log(OPERATION . ":NG:" . $log_msg);
+                syserr_display();
+                exit(1);
+            /* ΥۥȤꤵ졢0郎ꤷ */
+            } else if ($ret === 3) {
+                mysqli_close($conn);
+                /* ֤ */
+                $tag["<<COMMENT_START>>"]       = "";
+                $tag["<<COMMENT_END>>"]         = "";
+                $tag["<<SEARCH_COUNT>>"]        = '0';
+                $err_msg = sprintf($msgarr['28022'][SCREEN_MSG], '0');
+                /* ݻhidden */
+                make_hidden($post, $tag);
+                /* ɥܥ󲡲 */
+                if (isset($_POST["download_button"])) {
+                    /* ե̾ƥȥ꡼ॻå */
+                    $fn = "log_" . date("YmdHis") . ".csv";
+                    header("Content-Disposition: attachment; filename=\"$fn\"");
+                    header("Content-Type: application/octet-stream");
+                    exit(0);
+                }
+            } else if ($ret === 0) {
+                /* MySQL */
+                $result = MySQL_exec_query($conn, $search_sql);
+                $err_num = 0;
+                if ($result === FALSE) {
+                    $err_num = mysqli_errno($conn);
+                    mysqli_close($conn);
+
+                    /* ɽǤʤʤ꼺Ԥϥƥ२顼 */
+                    if ($err_num != REGEXP_ERR_NUM) {
+                        result_log(OPERATION . ":NG:" . $log_msg);
+                        syserr_display();
+                        exit(1);
+                   }
+                }
 
-                /* ɽǤʤʤ꼺Ԥϥƥ२顼 */
                 if ($err_num != REGEXP_ERR_NUM) {
+                    /* MySQLϿ줿ơ֥ξ˳Ǽ */
+                    MySQL_get_data($result, $data);
+                    mysqli_close($conn);
+
+                    /* ɥܥ󲡲 */
+                    if (isset($_POST["download_button"])) {
+                        /* ե̾ƥȥ꡼ॻå */
+                        $fn = "log_" . date("YmdHis") . ".csv";
+                        header("Content-Disposition: attachment; filename=\"$fn\"");
+                        header("Content-Type: application/octet-stream");
+                        /* ǡ򥢥ȥץå */
+                        printCSV($data);
+                        exit(0);
+                    }
+
+                    /* ֤ */
+                    $data_count = count($data);
+                    $tag["<<COMMENT_START>>"]       = "";
+                    $tag["<<COMMENT_END>>"]         = "";
+                    $tag["<<SEARCH_COUNT>>"]        = $data_count;
+                    $err_msg = sprintf($msgarr['28022'][SCREEN_MSG], $data_count);
+
+                    /* ɽη */
+                    get_page($data, $page, $tag);
+
+                    /* ݻhidden */
+                    make_hidden($post, $tag);
+
+                    /* 롼ץκ */
+                    set_loop_tag($data, $page, $looptag);
+
+                } else {
+
+                   $err_msg = $msgarr['28026'][SCREEN_MSG];
+
+                   /*  */
+                   result_log(OPERATION . ":NG:" . $log_msg);
+                }
+
+            } else {
+                /*  */
+                result_log(OPERATION . ":NG:" . $log_msg);
+            }
+
+        /* פ "elasticsearch" ξ */
+        } else if ($web_conf['sylas']['searchtype'] === ELASTICSEARCH) {
+
+            /* 롼פ򸡺 */
+            $ret = get_loggroup($conn, $post['loggroup'], $groupdata);
+
+            /* ƥ२顼(MYSQL³顼) */
+            if ($ret === 2) {
+                mysqli_close($conn);
+                result_log(OPERATION . ":NG:" . $log_msg);
+                syserr_display();
+                exit(1);
+
+            /* 롼פ¸ߤ */
+            } else if ($ret === 0) {
+
+                mysqli_close($conn);
+                /* elasticsearchǡ */
+                $elastic_data = get_elasticdata($groupdata, $post);
+
+                /* оݤelasticsearchФ³Ǥʤä */
+                if ($elastic_data === FALSE) {
+                    $err_msg = sprintf($msgarr['50000'][SCREEN_MSG], LOG_NAME_DISP);
+                    $log_msg = sprintf($msgarr['50000'][LOG_MSG], LOG_NAME_LOG);
                     result_log(OPERATION . ":NG:" . $log_msg);
                     syserr_display();
                     exit(1);
-               }
-            }
+                }
+                   
+                /* elasticserach֤ͤjsonǥ */
+                $xmlarr = json_decode($elastic_data);
 
-            if ($err_num != REGEXP_ERR_NUM) {
-                /* MySQLϿ줿ơ֥ξ˳Ǽ */
-                MySQL_get_data($result, $data);
-                mysqli_close($conn);
+                /* jsonǥɤɬפͤ */
+                $data = extract_values($xmlarr);
+
+                /* Ի */
+                if ($data === false) {
+                    result_log(OPERATION . ":NG:" . $log_msg);
+                    $data = "";
+                }
 
                 /* ɥܥ󲡲 */
                 if (isset($_POST["download_button"])) {
@@ -446,33 +530,29 @@ if (isset($_POST["search_button"]) || isset($_POST["download_button"])) {
                     exit(0);
                 }
 
-                /* ֤ */
-                $data_count = count($data);
-                $tag["<<COMMENT_START>>"]       = "";
-                $tag["<<COMMENT_END>>"]         = "";
-                $tag["<<SEARCH_COUNT>>"]        = $data_count;
-                $err_msg = sprintf($msgarr['28022'][SCREEN_MSG], $data_count);
+                /* ִ ̤¸ߤ */
+                if ($data !== "") {
+                    $data_count = count($data);
+                    $tag["<<COMMENT_START>>"]       = "";
+                    $tag["<<COMMENT_END>>"]         = "";
+                    $tag["<<SEARCH_COUNT>>"]        = $data_count;
+                    $err_msg = sprintf($msgarr['28022'][SCREEN_MSG], $data_count);
 
-                /* ɽη */
-                get_page($data, $page, $tag);
+                    /* ɽη */
+                    get_page($data, $page, $tag);
 
-                /* ݻhidden */
-                make_hidden($post, $tag);
+                    /* ݻhidden */
+                    make_hidden($post, $tag);
 
-                /* 롼ץκ */
-                set_loop_tag($data, $page, $looptag);
+                    /* 롼ץκ */
+                    set_loop_tag($data, $page, $looptag);
+                };
 
             } else {
-
-               $err_msg = $msgarr['28026'][SCREEN_MSG];
-
-               /*  */
-               result_log(OPERATION . ":NG:" . $log_msg);
+                mysqli_close($conn);
+                /*  */
+                result_log(OPERATION . ":NG:" . $log_msg);
             }
-
-        } else {
-            /*  */
-            result_log(OPERATION . ":NG:" . $log_msg);
         }
 
     } else {
