@@ -649,23 +649,66 @@ function exec_mail_search($post)
         return(2);
     }
 
-    /*MailSQL*/
-    make_mail_search_sql($post, $search_sql, $conn);
+    /* פ "MYSQL" ξ */
+    if ($web_conf['sylas']['searchtype'] === MYSQL) {
 
-    /*MySQL*/
-    $result = MySQL_exec_query($conn, $search_sql);
-    if ($result === FALSE) {
+        /*MailSQL*/
+        make_mail_search_sql($post, $search_sql, $conn);
+
+        /*MySQL*/
+        $result = MySQL_exec_query($conn, $search_sql);
+        if ($result === FALSE) {
+            mysqli_close($conn);
+            return(2);
+        }
+
+        /*MySQLϿ줿ơ֥ξ˳Ǽ*/
+        MySQL_get_data($result, $data);
         mysqli_close($conn);
-        return(2);
-    }
 
-    /*MySQLϿ줿ơ֥ξ˳Ǽ*/
-    MySQL_get_data($result, $data);
-    mysqli_close($conn);
+    /* פ "elasticsearch" ξ */
+    } else if ($web_conf['sylas']['searchtype'] === ELASTICSEARCH) {
+
+        /* 롼פ򸡺 */
+        $ret = get_loggroup($conn, $post['loggroup'], $groupdata);
+        mysqli_close($conn);
+
+        /* ƥ२顼(MYSQL³顼) */
+        if ($ret === 2) {
+            result_log(OPERATION . ":NG:" . $log_msg);
+            return(1);
+
+        /* 롼פ¸ߤ */
+        } else if ($ret === 0) {
+
+            $gettype = "mail";
+            /* elasticsearchǡ */
+            $elastic_data = get_elasticdata($groupdata, $post, $gettype);
+
+            /* оݤelasticsearchФ³Ǥʤä */
+            if ($elastic_data === NULL) {
+                $err_msg = sprintf($msgarr['50000'][SCREEN_MSG], LOG_NAME_DISP);
+                $log_msg = sprintf($msgarr['50000'][LOG_MSG], LOG_NAME_LOG);
+                result_log(OPERATION . ":NG:" . $log_msg);
+                syserr_display();
+                return(1);
+            }
+
+            /* elasticserach֤ͤjsonǥ(Ϣ) */
+            $xmlarr = json_decode($elastic_data);
+            /* jsonǥɤɬפͤ */
+            $data = extract_values($xmlarr);
+
+            /* Ի */
+            if ($data === false) {
+                return(1);
+            }
+        }
+    }
 
     /*ǡ١Ǥη$maxsearch*/
     $maxsearch = count($data);
-    
+
     if ($maxsearch >= $web_conf['sylas']['maxsearchcount']) {     
         unset($data[$maxsearch -1]);
     }
